package WebGUI::i18n::English::Asset_Gallery;

our $I18N = { 
    'assetName' => {
        message     => 'Gallery',
        lastUpdated => 1131394072,
    },
    "groupIdAddComment label" => {
        message     => "Group to Add Comments",
        lastUpdated => 0,
        context     => '',
    },
    "groupIdAddComment description" => {
        message     => "The group that is allowed to add comments to files.",
        lastUpdated => 0,
        context     => '',
    },
    "groupIdAddFile label" => {
        message     => "Group to Add Files",
        lastUpdated => 0,
        context     => '',
    },
    "groupIdAddFile description" => {
        message     => "The group that is allowed to add files and albums to this gallery",
        lastUpdated => 0,
        context     => '',
    },
    "groupIdModerator label" => {
        message     => "Group to Moderate Comments",
        lastUpdated => 0,
        context     => '',
    },
    "groupIdModerator description" => {
        message     => "The group that is allowed to edit / delete comments in this gallery",
        lastUpdated => 0,
        context     => '',
    },
    "imageResolutions label" => {
        message     => "Image Resolutions",
        lastUpdated => 0,
        context     => '',
    },
    "imageResolutions description" => {
        message     => "The sizes of images (in pixels) available for download. This number is the maximum height or width that the image will have.",
        lastUpdated => 0,
        context     => '',
    },
    "imageViewSize label" => {
        message     => "Image View Size",
        lastUpdated => 0,
        context     => '',
    },
    "imageViewSize description" => {
        message     => "The size (in pixels) for images in the gallery. Will default to the Image Size 
                        in the site settings.",
        lastUpdated => 0,
        context     => '',
    },
    "imageThumbnailSize label" => {
        message     => "Image Thumbnail Size",
        lastUpdated => 0,
        context     => '',
    },
    "imageThumbnailSize description" => {
        message     => "The size (in pixels) for thumbnails of images in the gallery. Will default to the 
                        Thumbnail Size in the site settings.",
        lastUpdated => 0,
        context     => '',
    },
    "maxSpacePerUser label" => {
        message     => "Max Disk Space Per User",
        lastUpdated => 0,
        context     => '',
    },
    "maxSpacePerUser description" => {
        message     => "The maximum amount of disk space (in megabytes) a user is allowed to use in this Gallery. Each image will take up to 6 megabytes depending on what resolutions and density you choose.",
        lastUpdated => 0,
        context     => '',
    },
    "richEditIdAlbum label" => {
        message     => "Rich Editor for Albums",
        lastUpdated => 0,
        context     => 'Asset property label',
    },
    "richEditIdAlbum description" => {
        message     => "The Rich Text Editor to use for Albums",
        lastUpdated => 0,
        context     => 'Asset property description',
    },
    "richEditIdFile label" => {
        message     => "Rich Editor for Files",
        lastUpdated => 0,
        context     => 'Asset property label',
    },
    "richEditIdFile description" => {
        message     => "The Rich Text Editor to use for Files",
        lastUpdated => 0,
        context     => 'Asset property description',
    },
    "richEditIdFileComment label" => {
        message     => "Rich Editor for Comments",
        lastUpdated => 0,
        context     => '',
    },
    "richEditIdFileComment description" => {
        message     => "The Rich Text Editor to use for comments",
        lastUpdated => 0,
        context     => '',
    },
    'search class galleryalbum' => {
        message     => 'Album',
        lastUpdated => 0,
        context     => 'Asset name for WebGUI::Asset::Wobject::GalleryAlbum',
    },
    'search class any' => {
        message     => 'Any',
        lastUpdated => 0,
        context     => 'Label to not restrict gallery search by class',
    },
    'search class photo' => {
        message     => "Photo",
        lastUpdated => 0,
        context     => 'Asset name for WebGUI::Asset::File::Image::Photo class',
    },
    "search submit" => {
        message     => "Search",
        lastUpdated => 0,
        context     => 'Label for button to submit search form',
    },

    "templateIdAddArchive label" => {
        message     => "Template to Add Multiple",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdAddArchive description" => {
        message     => "Display the form to add an archive of files to the gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdDeleteAlbum label" => {
        message     => "Template to Delete Albums",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdDeleteAlbum description" => {
        message     => "Display the confirmation to delete an album from the gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdDeleteFile label" => {
        message     => "Template to Delete Files",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdDeleteFile description" => {
        message     => "Display the confirmation to delete a file from the gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditAlbum label" => {
        message     => "Template to Edit Albums",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditAlbum description" => {
        message     => "The template to add / edit an album.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditComment label" => {
        message     => "Template to Edit Comments",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditComment description" => {
        message     => "The template to edit a comment.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditFile label" => {
        message     => "Template to Edit Files",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdEditFile description" => {
        message     => "The template to add / edit a file.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListAlbums label" => {
        message     => "Template to List Albums",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListAlbums description" => {
        message     => "Template to show a list of albums in the gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListAlbumsRss label" => {
        message     => "Template to List Albums RSS",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListAlbumsRss description" => {
        message     => "Template to show an RSS feed of the albums in this gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdMakeShortcut label" => {
        message     => "Template to Cross Post Files",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdMakeShortcut description" => {
        message     => "Display the form to copy an image to another album.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdSearch label" => {
        message     => "Template to Search",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdSearch description" => {
        message     => "Display the form to search the gallery. Display search results.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewSlideshow label" => {
        message     => "Template for Slideshow",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewSlideshow description" => {
        message     => "Display all the images in an album as a slideshow.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewThumbnails label" => {
        message     => "Template for Thumbnails",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewThumbnails description" => {
        message     => "Display all the images in an album as their thumbnails",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListFilesForUser label" => {
        message     => "Template to List Files for User",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListFilesForUser description" => {
        message     => "Display all the files and albums for a specific user.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListFilesForUserRss label" => {
        message     => "Template to List Files for User RSS",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdListFilesForUserRss description" => {
        message     => "RSS feed for all the files for a specific user.",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewAlbum label" => {
        message     => "Template to View Album",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewAlbum description" => {
        message     => "Default view for albums",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewAlbumRss label" => {
        message     => "Template to View Album RSS",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewAlbumRss description" => {
        message     => "RSS feed for a single album",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewFile label" => {
        message     => "Template to View a File",
        lastUpdated => 0,
        context     => '',
    },
    "templateIdViewFile description" => {
        message     => "Show the details and comments for a specific file",
        lastUpdated => 0,
        context     => '',
    },
    "viewDefault label" => {
        message     => "Default View",
        lastUpdated => 0,
        context     => '',
    },
    "viewDefault description" => {
        message     => "Select the default view when a user enters the gallery.",
        lastUpdated => 0,
        context     => '',
    },
    "viewDefault option list" => {
        message     => "List Albums",
        lastUpdated => 0,
        context     => '',
    },
    "viewDefault option album" => {
        message     => "Single Album",
        lastUpdated => 0,
        context     => '',
    },
    "viewAlbumAssetId label" => {
        message     => "Default View Album",
        lastUpdated => 0,
        context     => '',
    },
    "viewAlbumAssetId description" => {
        message     => "The album to view when the default view is 'Single Album'",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderBy label" => {
        message     => "List Albums Order By",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderBy description" => {
        message     => "The field to order the album list by",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderBy option creationDate" => {
        message     => "Creation Date",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderBy option lineage" => {
        message     => "Sequence Number",
        lastUpdated => 0,
        context     => 'Label to order by sequence (as in asset manager)',
    },
    "viewListOrderBy option revisionDate" => {
        message     => "Revision Date",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderBy option title" => {
        message     => "Title",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderDirection label" => {
        message     => "List Albums Direction",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderDirection description" => {
        message     => "The direction to order the album list",
        lastUpdated => 0,
        context     => '',
    },
    "viewListOrderDirection option asc" => {
        message     => "Ascending",
        lastUpdated => 0,
        context     => 'Label for sorting in ascending order',
    },
    "viewListOrderDirection option desc" => {
        message     => "Descending",
        lastUpdated => 0,
        context     => 'Label for sorting in descending order',
    },
    "workflowIdCommit label" => {
        message     => "Approval Workflow",
        lastUpdated => 0,
        context     => '',
    },
    "workflowIdCommit description" => {
        message     => "Workflow to approve new Files.",
        lastUpdated => 0,
        context     => '',
    },

    'helpvar searchForm_start' => {
        message     => 'Begin the form to search the Gallery.',
        lastUpdated => 0,
    },

    'helpvar searchForm_end' => {
        message     => 'End the form to search the Gallery.',
        lastUpdated => 0,
    },

    'helpvar searchForm_basicSearch' => {
        message     => 'The basic search input box. Will search the title, 
                        description, keywords, and user defined fields.',
        lastUpdated => 0,
    },

    'helpvar searchForm_title' => {
        message     => 'Search by title.',
        lastUpdated => 0,
    },

    'helpvar searchForm_description' => {
        message     => 'Search by description.',
        lastUpdated => 0,
    },

    'helpvar searchForm_keywords' => {
        message     => 'Search by keyword.',
        lastUpdated => 0,
    },
    
    'helpvar searchForm_location' => {
        message     => 'Search by location.',
        lastUpdated => 0,
    },    

    'helpvar searchForm_className' => {
        message     => 'Search by class name.',
        lastUpdated => 0,
    },

    'helpvar searchForm_creationDate_after' => {
        message     => 'Limit search to assets created after this date-time.',
        lastUpdated => 0,
    },

    'helpvar searchForm_creationDate_before' => {
        message     => 'Limit search to assets created before this date-time.',
        lastUpdated => 0,
    },

    'helpvar searchForm_submit' => {
        message     => 'Submit the search form.',
        lastUpdated => 0,
    },

    'helpvar url_addAlbum' => {
        message     => 'URL to add an album to the gallery.',
        lastUpdated => 0,
    },

    'helpvar url_listAlbums' => {
        message     => 'URL to list the albums in the gallery.',
        lastUpdated => 0,
    },

    'helpvar url_listAlbumsRss' => {
        message     => 'URL to the RSS feed for the list of albums.',
        lastUpdated => 0,
    },

    'helpvar url_listFilesForCurrentUser' => {
        message     => 'URL to list albums and files for the current user.',
        lastUpdated => 0,
    },

    'helpvar url_search' => {
        message     => 'URL to the search page.',
        lastUpdated => 0,
    },

    'helpvar canEdit' => {
        message     => 'This var is true if the user can edit the gallery.',
        lastUpdated => 0,
    },

    'helpvar canAddFile' => {
        message     => 'This var is true if the user can add albums and files to the gallery.',
        lastUpdated => 0,
    },

    'helpvar albums' => {
        message     => 'This is the loop over the albums being currently displayed.',
        lastUpdated => 0,
    },

    'helpvar albums rss' => {
        message     => 'A loop containing an RSS feed for albums in the gallery.',
        lastUpdated => 1231287030,
    },

    'helpvar rssDate' => {
        message     => 'This is the RFC2822-compatible date that RSS feeds need for the pubDate field',
        lastUpdated => 0,
    },

    'helpvar search_results' => {
        message     => 'This is the loop over the search results.',
        lastUpdated => 0,
    },

    'helpvar user_albums' => {
        message     => q{This is the loop over the user's albums. All the user's albums will be
                    in this loop.},
        lastUpdated => 0,
    },

    'helpvar user_files' => {
        message     => q{This is the loop over the user's files. Only the files on this page of 
                    the results will be shown.},
        lastUpdated => 0,
    },

    'helpvar userId' => {
        message     => 'The ID of the user currently being shown in the listFilesForUser page',
        lastUpdated => 0,
    },

    'helpvar url_rss' => {
        message     => q{The URL to the RSS feed for this user's files and albums},
        lastUpdated => 0,
    },

    'helpvar username' => {
        message     => 'The username of the user currently shown on the listFilesForUser page',
        lastUpdated => 0,
    },
    
    'help searchForm title' => {
        message     => 'Gallery Search Form Variables',
        lastUpdated => 0,
    },

    'help searchForm body' => {
        message     => 'These variables are available from all Gallery views and allow you to
                        create a form to search the Gallery.',
        lastUpdated => 0,
    },

    'help common title' => {
        message     => 'Gallery Variables (Common)',
        lastUpdated => 0,
    },

    'help common body' => {
        message     => 'These variables are common to all Gallery views.',
        lastUpdated => 0,
    },

    'help listAlbums title' => {
        message     => 'Gallery List Albums Variables',
        lastUpdated => 0,
    },

    'help listAlbums body' => {
        message     => 'These variables are available on the listAlbums view of the Gallery',
        lastUpdated => 0,
    },

    'help listAlbumsRss title' => {
        message     => 'Gallery List Albums RSS Variables',
        lastUpdated => 0,
    },
    
    'help listAlbumsRss body' => {
        message     => 'These variables are available on the listAlbums RSS feed.',
        lastUpdated => 0,
    },

    'help search title' => {
        message     => 'Gallery Search Results Variables',
        lastUpdated => 0,
    },

    'help search body' => {
        message     => 'These variables are available from the search results screen of the gallery.',
        lastUpdated => 0,
    },

    'help listFilesForUser title' => {
        message     => 'Gallery List Files For User Variables',
        lastUpdated => 0,
    },

    'help listFilesForUser body' => {
        message     => 'These variables are available from the listFilesForUser screen of the Gallery.',
        lastUpdated => 0,
    },

    'help listFilesForUserRss title' => {
        message     => 'Gallery List Files For User RSS Variables',
        lastUpdated => 0,
    },

    'help listFilesForUserRss body' => {
        message     => 'These variables are available for the listFilesForUser RSS feed.',
        lastUpdated => 0,
    },

    'template search title' => {
        message     => "Advanced Search",
        lastUpdated => 0,
        context     => "Title for the www_search page. Used to show the Advanced search form",
    },

    'template search field title' => {
        message     => "Title",
        lastUpdated => 0,
        context     => "Label for the 'Title' input for the search form",
    },

    'template search field description' => {
        message     => "Description",
        lastUpdated => 0,
        context     => "Label for the 'Description' input for the search form",
    },

    'template search field keywords' => {
        message     => "Tags",
        lastUpdated => 0,
        context     => "Label for the 'Keywords' input for the search form. 'Tags' is used because Keywords may be confused with the generic, all-inclusive search box.",
    },
    
    'template search field location' => {
        message     => "Location",
        lastUpdated => 0,
        context     => "Label for the 'Location' input for the search form.",
    },

    'template search field className' => {
        message     => "Search Type",
        lastUpdated => 0,
        context     => "Label for the 'className' input for the search form. 'Type' is used because 'Class' has no meaning to a normal user.",
    },

    'template search field creationDate' => {
        message     => "Date",
        lastUpdated => 0,
        context     => "Label for the 'creation date' input for the search form",
    },

    'template search to' => {
        message     => "to",
        lastUpdated => 0,
        context     => "Joins the 'before' and 'after' parts of the Creation Date inputs.",
    },

    'template search results for' => {
        message     => "Results for",
        lastUpdated => 0,
        context     => "Title for the results section. 'for' leads into the string that was searched for.",
    },

    'template by' => {
        message     => 'By',
        lastUpdated => 0,
        context     => q{Lead-in for the author of an Album or Photo},
    },

    'template galleryalbum url' => {
        message     => 'View Album',
        lastUpdated => 0,
        context     => 'Label for link from List Albums view to GalleryAlbum view',
    },

    'template url_search'   => {
        message     => 'Advanced Search',
        lastUpdated => 0,
        context     => 'Label for link to the Gallery search page.',
    },

    'template url_listFilesForCurrentUser' => {
        message     => 'My Gallery',
        lastUpdated => 0,
        context     => q{Label for link to view the current user's files and albums.},
    },

    'template listFilesForUser title' => {
        message     => q{%s's Gallery},
        lastUpdated => 0,
        context     => q{Label for List Files For User view. '%s' will be replaced with the username},
    },

    'template listFilesForUser albums title' => {
        message     => q{My Albums},
        lastUpdated => 1230576660,
        context     => q{Title for list of user's Albums},
    },

    'template listFilesForUser pictures title' => {
        message     => q{My Pictures},
        lastUpdated => 1230576660,
        context     => q{Title for list of user's Pictures},
    },

    'template listFilesForUser albums files' => {
        message     => q{files},
        lastUpdated => 0,
        context     => q{Label for number of files in the Album},
    },

    'template url_addAlbum' => {
        message     => q{Add an Album},
        lastUpdated => 0,
        context     => q{Label for the link to add an Album},
    },

    'error add uncommitted' => {
        message     => q{<h1>Error!</h1><p>You must commit this Gallery before adding albums</p>},
        lastUpdated => 0,
        context     => q{Error message when trying to add albums to uncommitted Gallery assets},
    },

    'helpvar isAlbum' => {
        message     => q{This variable is true if the current result is a GalleryAlbum.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'defaultFilesPerPage label' => {
        message     => q{Default Files Per Page},
        lastUpdated => 0,
        context     => q{Asset property label},
    },

    'defaultFilesPerPage description' => {
        message     => q{The number of files to show per page of the album view.},
        lastUpdated => 0,
        context     => q{Description of asset property},
    },

    'imageDensity label' => {
        message     => q{Image Density},
        lastUpdated => 0,
        context     => q{Label for asset property},
    },

    'imageDensity description' => {
        message     => q{The density of the image. Print-quality images are more than three times the resolution of web-quality images.},
        lastUpdated => 1231764657,
        context     => q{Description of asset property},
    },

    'imageDensity option web' => {
        message     => q{Web quality (72 pixels per inch)},
        lastUpdated => 0,
        context     => q{Option label for 72 pixels-per-inch images, the highest that monitors can display},
    },

    'imageDensity option print' => {
        message     => q{Print quality (300 pixels per inch)},
        lastUpdated => 0,
        context     => q{Option label for 300 pixels-per-inch images, good for printing images},
    },

    'template listAlbumsRss' => {
        message     => 'Subscribe',
        lastUpdated => 1237403207,
        context     => 'Label for link to RSS feed.',
    },

    'template search basic title' => {
        message     => 'Search Gallery',
        lastUpdated => 1237403442,
        context     => 'Title for basic search form in page.',
    },

    'template search basic term' => {
        message     => 'Search Term',
        lastUpdated => 1237403498,
        context     => 'Title for basic search term field in page.',
    },

};

1;
